@@ -6,6 +6,7 @@ var app = new Vue({
         error_summary: [],
         contributor_index: 2,
         extra_index: 0,
+        allowed_add_data: false,
         form: {
             title: '',
             id: '',
@@ -242,10 +243,8 @@ var app = new Vue({
             formData.append('private', this.form.visibility)
             formData.append('url', this.form.source)
             formData.append('version', this.form.version)
-            formData.append('author', this.form.contributors[0].name)
-            formData.append('author_email', this.form.contributors[0].email)
-            formData.append('maintainer', this.form.contributors[1].name)
-            formData.append('maintainer_email', this.form.contributors[1].email)
+            formData.append('author', this.form.contributors[1].name)
+            formData.append('author_email', this.form.contributors[1].email)
             formData.append('metadata', JSON.stringify(this.form))
             axios.post("/datapackage-creator/save-package", formData, { headers }).then((res) => {
                 this.error_summary = []
@@ -260,5 +259,11 @@ var app = new Vue({
                 }
             })
         }
+    },
+    computed: {
+        allowedAddData() {
+            return this.form.title && this.form.notes && this.form.license && this.form.tags &&
+            this.form.contributors[1].name && this.form.contributors[1].email
+        }
     }
 })
\ No newline at end of file
